// Copyright (C) 2009 Playedit.

// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.

// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.

#ifndef MTP_ACTIONS_H
#define MTP_ACTIONS_H

#include "mtp_data_types.h"

typedef struct LIBMTP_mtpdevice_struct LIBMTP_mtpdevice_t;

class MTPDevice
{
	public:
		MTPDevice(int (*progress_callback)(const uint64_t, const uint64_t, const void*),
				void* callback_data);
		~MTPDevice();

		inline operator bool() { return m_Device; };
		inline bool IsReady() { return m_Device && m_IsReady; };
		void SetReady(const bool ready = true);
		void Connect(int devnum);
		void Disconnect();
		int DevNum() { return m_DevNum; };
		Glib::ustring DeviceName();
		void SetDeviceName(const Glib::ustring& name);

		bool UpdatePlaylist(const Glib::RefPtr<playlist_t>& playlist);
		bool SetPlaylistName(const Glib::RefPtr<playlist_t>& playlist, const std::string& name);
		bool CreateNewPlaylist(const Glib::RefPtr<playlist_t>& playlist);
		Glib::RefPtr<playlist_t> GetPlaylist(const uint32_t id);

		bool CreateNewTrack(const Glib::ustring& filename,
				const Glib::RefPtr<track_t>& track);
		bool UpdateTrack(const Glib::RefPtr<track_t>& track);
		bool CreateNewAlbum(const Glib::RefPtr<album_t>& album);
		bool UpdateAlbum(const Glib::RefPtr<album_t>& album);
		bool SetAlbumArt(const Glib::RefPtr<album_t>& album, const Glib::ustring& filename);

		bool DeleteObject(const uint32_t id);

		void GetMusicLists(std::vector<album_pair_t>& album_list);
		void GetPlaylistList(std::vector< Glib::RefPtr<playlist_t> >& playlist_list);

	private:
		void DumpErrorStack(const Glib::ustring& message);
		void GetAlbumArt(const Glib::RefPtr<album_t>& album);

		LIBMTP_mtpdevice_t* m_Device;
		int m_DevNum;
		int (*m_ProgressCallback)(const uint64_t, const uint64_t, const void*);
		void* m_CallbackData;
		bool m_IsReady;
};

#endif // MTP_ACTIONS_H
